@@ -84,8 +84,9 @@ convert <- function(text,
       "<=" = "\\leq ",
       "\n" = "\\line ",
       "\\pagenumber" = "\\chpgn ",
-      "\\totalpage" = "\\totalpage ",
-      "\\pagefield" = "{\\field{\\*\\fldinst NUMPAGES }} "
+      "\\totalpage" = "\\totalpage",
+      "\\pagefield" = "{\\field{\\*\\fldinst NUMPAGES }} ",
+      "\\pagenumber_hardcoding" = "\\pgnhardcoding"
     )
 
     # Define Pattern for latex code
