@@ -70,7 +70,7 @@ rtf_encode_figure <- function(tbl) {
 
   start_rtf <- paste(
     as_rtf_init(),
-    as_rtf_font(),
+    as_rtf_font(tbl),
     as_rtf_color(tbl),
     sep = "\n"
   )
