@@ -89,6 +89,9 @@ rtf_source <- function(tbl,
     tbl <- rtf_page(tbl)
   }
 
+  # Get use_i18n from page attributes
+  use_i18n <- attr(tbl, "page")$use_i18n %||% FALSE
+
   # Define text object
   source <- obj_rtf_text(source,
     text_font,
@@ -105,7 +108,8 @@ rtf_source <- function(tbl,
     text_space_after,
     text_new_page = FALSE,
     text_hyphenation = TRUE,
-    text_convert = text_convert
+    text_convert = text_convert,
+    use_i18n = use_i18n
   )
 
   if (attr(source, "use_color")) attr(tbl, "page")$use_color <- TRUE
