@@ -76,8 +76,8 @@ cellsize <- matrix(width, nrow = nrow(tbl), ncol = ncol(tbl), byrow = TRUE) - pa
 nline_vector <- rtf_nline_vector(
   text = c("title 1", "this is a sentence for title 2", NA),
   strwidth = c(
-    strwidth("title 1", units = "inches"),
-    strwidth("this is a sentence for title 2", units = "inches")
+    r2rtf:::with_graphics_device(graphics::strwidth("title 1", units = "inches")),
+    r2rtf:::with_graphics_device(graphics::strwidth("this is a sentence for title 2", units = "inches"))
   ),
   size = 0.5
 )
@@ -105,7 +105,6 @@ irspagebybodys <- attr(attr(irs1, "rtf_pageby_table"), "rtf_nrow")
 irspagebyrows <- attr(attr(irs1, "rtf_pageby_row")$Species, "rtf_nrow")
 
 
-
 test_that("test if rtf_nline_vector() return to correct numbers", {
   # line for first vector
   expect_equal(nline_vector[1], 1)
